SampleCurrencyData class

  1. Define a minimal explicit data model for the example ecosystem.

Constructors

SampleCurrencyData({required String id, required String symbol, required String name})
SampleCurrencyData.fromJson(Map<String, dynamic> json)
Factory factory mapper mapping direct JSON keys to object parameters.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbol String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited